%Script to print a loan repayment table
%If a regular fixed payment P is made n times a year to repay a loan of 
%amount A over a period of k years, where the nominal annual interest 
%rate is r, P is given by:
% P = r * A * (1 + r/n)^(n*k) / (n * ((1 + r/n)^(n*k) - 1));
%Generate a table of repayments for a loan of $1000 over 15, 20, or 25 years, 
%at interest rates that vary from 10% to 20% per annum, in steps of 1%. 
%Since P is directly proportional to A in the above formula, the repayments
%of a loan of any amount can be found by simple proportion from such a table.

A = 1000;
n = 12; 

%outer loop
for r = 0.1 : 0.01: 0.2
    fprintf('%4.0f%', 100*r);
    %inner loop
    for k = 15:5:25
        temp = (1 + r/n)^(n*k);
        P = r * A * temp / (n * (temp - 1));
        fprintf('%10.2f', P);
    end
    fprintf('\n');
end

% Alternative faster version which vectorizes the inner loop

%loop
for r = 0.1 : 0.01: 0.2
     k = 15:5:25;
     temp = (1 + r/n) .^ (n*k);
     P = r * A * temp ./ (n * (temp - 1));
     disp([100*r, P]);
end